grab.spider.errors — Grab 0.6.41 documentation

# `grab.spider.errors`

## Module Contents

exception grab.spider.errors.SpiderError

  Bases: `grab.errors.GrabError`

  Base class for Spider exceptions.

exception grab.spider.errors.SpiderMisuseError

  Bases: `SpiderError`

  Improper usage of Spider framework.

exception grab.spider.errors.FatalError

  Bases: `SpiderError`

  Fatal error which should stop parsing process.

exception grab.spider.errors.SpiderInternalError

  Bases: `SpiderError`

  Raises when error throwned by internal spider logic.

  Like spider class discovering, CLI error.

exception grab.spider.errors.NoTaskHandler

  Bases: `SpiderError`

  Raise when no handler found to process network response.

exception grab.spider.errors.NoDataHandler

  Bases: `SpiderError`

  Raise when no handler found to process Data object.